<?php

namespace Drupal\editorial_access_manager\Plugin\EntityReferenceSelection;

use Drupal\user\Plugin\EntityReferenceSelection\UserSelection;
use Drupal\user\UserInterface;

/**
 * Provides selection for assignable users.
 *
 * @EntityReferenceSelection(
 *   id = "editorial_access_manager_assignable_user",
 *   label = @Translation("Assignable user"),
 *   entity_types = {"user"},
 *   group = "editorial_access_manager",
 *   weight = 1
 * )
 */
class AssignableUserSelection extends UserSelection {

  /**
   * {@inheritdoc}
   */
  public function getReferenceableEntities($match = NULL, $match_operator = 'CONTAINS', $limit = 0) {
    $configuration = $this->getConfiguration();
    /** @var array $entities */
    $entities = parent::getReferenceableEntities($match, $match_operator, $limit);
    $entities['user'] = array_filter($entities['user'], function (int $uid) use ($configuration) {
      $user = $this->entityTypeManager->getStorage('user')->load($uid);
      if (!$user instanceof UserInterface) {
        return FALSE;
      }
      $user_can_edit_assigned_entity = $user->hasPermission('edit assigned entity');
      if (!empty($configuration['editorial_content_entity_type'])) {
        $user_can_edit_assigned_entity = $user_can_edit_assigned_entity || $user->hasPermission(sprintf('edit assigned %s', $configuration['editorial_content_entity_type']));
      }
      return $user_can_edit_assigned_entity;
    }, ARRAY_FILTER_USE_KEY);
    return $entities;
  }

}
